﻿using C1.WPF.Grid;
using System;
using System.CodeDom;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ImageCellTemplateBooking
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private DataTable _dtBookings;
        private string[] pilotNames = { "Yuri", "Chuck", "Amelia", "Wilbur" };
        private BookingViewModel _bookingViewModel;
        private MyCellFactory _cellFactory;

        public MainWindow()
        {
            InitializeComponent();
            _dtBookings = new DataTable();
            _bookingViewModel = new BookingViewModel();
            _dtBookings.Columns.Clear();

            //First column of type Person created
            _dtBookings.Columns.Add("Instructor", typeof(Person));
            _dtBookings.Columns.Add("Slot1", typeof(Booking));
            _dtBookings.Columns.Add("Slot2", typeof(Booking));
            _dtBookings.Columns.Add("Slot3", typeof(Booking));
            _dtBookings.Columns.Add("Slot4", typeof(Booking));

            PopulateDTBookings();
            DisplayBookings();
            flexgrid.DataContext = _dtBookings.DefaultView;
            _cellFactory = new MyCellFactory(Resources["myDatatemplateSelector"] as MyTemplateSelector);
            flexgrid.CellFactory = _cellFactory;
            flexgrid.PreviewMouseLeftButtonDown += Flexgrid_MouseLeftButtonDown;
        }

        private void Flexgrid_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            var grid = sender as FlexGrid;
            GridHitTestInfo gridHitTestInfo = grid.HitTest(e);
            _cellFactory.UpdateCellsList((gridHitTestInfo.Row, gridHitTestInfo.Column));
            grid.Refresh(GridCellType.Cell, gridHitTestInfo.CellRange);
                
        }

        public void PopulateDTBookings()
        {
            DataRow dataRow;
            int i = 0;
            foreach (var p in pilotNames)
            {
                dataRow = _dtBookings.NewRow();
                Person pilot = new Person(p, ++i);
                dataRow[0] = pilot;
                _dtBookings.Rows.Add(dataRow);
            }
        }

        public void DisplayBookings()
        {

            foreach (var bookingItem in _bookingViewModel.BookingsList)
            {
                _dtBookings.Rows[bookingItem.PilotID - 1][bookingItem.SlotNo] = bookingItem;
            }
        }

    }
}
